From 57105b0741d1a823caefc0a7fcfa55e4f19c2bd1 Mon Sep 17 00:00:00 2001
From: Cameron Nemo <cnemo@tutanota.com>
Date: Fri, 31 May 2019 07:47:14 +0000
Subject: [PATCH 1/3] New package: containers.image-1.5.1

---
 srcpkgs/containers.image/template | 28 ++++++++++++++++++++++++++++
 1 file changed, 28 insertions(+)
 create mode 100644 srcpkgs/containers.image/template

diff --git a/srcpkgs/containers.image/template b/srcpkgs/containers.image/template
new file mode 100644
index 00000000000..13f0bd4e641
--- /dev/null
+++ b/srcpkgs/containers.image/template
@@ -0,0 +1,28 @@
+# Template file for 'containers.image'
+pkgname=containers.image
+version=1.5.1
+revision=1
+wrksrc="image-${version}"
+conf_files="/etc/containers/registries.conf"
+hostmakedepends="go-md2man"
+short_desc="Configuration shared by podman, buildah, and skopeo"
+maintainer="Cameron Nemo <cnemo@tutanota.com>"
+license="Apache-2.0"
+homepage="https://github.com/containers/image"
+distfiles="https://github.com/containers/image/archive/v${version}.tar.gz"
+checksum=369dd8a90eae5d25acd843f8eff5c571392a43582d3eced5bbdc4b3f0e81c551
+
+do_build() {
+	mkdir -p build
+	for doc in docs/*.*.md; do
+		docbase="${doc##*/}"
+		go-md2man -in "${doc}" -out "build/${docbase/.md/}"
+	done
+}
+
+do_install() {
+	for man in build/*; do
+		vman "${man}"
+	done
+	vinstall registries.conf 0644 etc/containers
+}

From f3359a39d633c1146d09a8be0f725f463aac199b Mon Sep 17 00:00:00 2001
From: Cameron Nemo <cnemo@tutanota.com>
Date: Fri, 31 May 2019 07:48:00 +0000
Subject: [PATCH 2/3] buildah: use registries.conf from containers.image

---
 srcpkgs/buildah/template | 13 ++++---------
 1 file changed, 4 insertions(+), 9 deletions(-)

diff --git a/srcpkgs/buildah/template b/srcpkgs/buildah/template
index dde0990be24..7355e1fa98c 100644
--- a/srcpkgs/buildah/template
+++ b/srcpkgs/buildah/template
@@ -1,7 +1,7 @@
 # Template file for 'buildah'
 pkgname=buildah
 version=1.8.2
-revision=1
+revision=2
 build_style=go
 go_import_path=github.com/containers/buildah
 go_package="${go_import_path}/cmd/buildah"
@@ -9,25 +9,20 @@ go_build_tags=containers_image_ostree_stub
 hostmakedepends="pkg-config go-md2man"
 makedepends="libostree-devel libbtrfs-devel device-mapper-devel gpgme-devel
  libassuan-devel libseccomp-devel"
-depends="runc skopeo"
-short_desc="OCI image building tool"
-maintainer="Cameron Nemo <camerontnorman@gmail.com>"
+depends="runc skopeo containers.image"
+short_desc="Dockerfile compatible OCI image building tool"
+maintainer="Cameron Nemo <cnemo@tutanota.com>"
 license="Apache-2.0"
 homepage="https://github.com/containers/buildah"
 distfiles="${homepage}/archive/v${version}.tar.gz"
 checksum=2a659687210fd1219c73e2d35e87caadb9e06f12e08973c18058d073fe8ecfb7
 
-case "$XBPS_TARGET_ARCH" in
-	*-musl) broken="/lib/libmount.so.1: undefined reference to getrandom" ;;
-esac
-
 post_build() {
 	make -C docs
 }
 
 post_install() {
 	vinstall contrib/completions/bash/buildah 644 /usr/share/bash-completion/completions
-	vinstall tests/registries.conf 644 /etc/containers
 	for _i in docs/*.1; do
 		vman $_i
 	done

From bba502815a6a7f8df34c51f9e23164e6a244ca91 Mon Sep 17 00:00:00 2001
From: Cameron Nemo <cnemo@tutanota.com>
Date: Fri, 31 May 2019 07:48:53 +0000
Subject: [PATCH 3/3] podman: update to 1.3.2

Drop buildah dependency for containers.image
---
 srcpkgs/podman/template | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/srcpkgs/podman/template b/srcpkgs/podman/template
index c3c5ea9ac98..b4b2564a709 100644
--- a/srcpkgs/podman/template
+++ b/srcpkgs/podman/template
@@ -1,6 +1,6 @@
 # Template file for 'podman'
 pkgname=podman
-version=1.3.1
+version=1.3.2
 revision=1
 wrksrc="libpod-${version}"
 build_style=go
@@ -10,13 +10,13 @@ go_build_tags="seccomp apparmor containers_image_ostree_stub
  btrfs_noversion exclude_graphdriver_btrfs"
 hostmakedepends="pkg-config go-md2man"
 makedepends="gpgme-devel libseccomp-devel device-mapper-devel"
-depends="runc cri-o cni-plugins skopeo buildah slirp4netns"
+depends="runc cri-o cni-plugins skopeo slirp4netns containers.image"
 short_desc="Simple management tool for containers and images"
 maintainer="Cameron Nemo <camerontnorman@gmail.com>"
 license="Apache-2.0"
 homepage="https://podman.io/"
 distfiles="https://github.com/containers/libpod/archive/v${version}.tar.gz"
-checksum=7ccbfa80900cd438468986911038da4c38382ef507a2fa717217faefb738fbc4
+checksum=ff860e009746ecf566c9228960e7721e8aeababbf9688e24724e6b31b0aefa00
 
 if [ "$CROSS_BUILD" ]; then
 	go_build_tags+=" containers_image_openpgp exclude_graphdriver_overlay"
